yakumo.nova.v2.key_pair.Manager

Package yakumo :: Package nova :: Package v2 :: Module key_pair :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for key pairs in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for key pairs in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.key_pair.Resource |
create(self, name=`'``__UNDEF__``'`, public_key=`'``__UNDEF__``'`) Register a SSH public key | source code
_find_gen(self, **kwargs) | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``name``'``,` `'``name``'``,` <yakumo.mapper.NoopClass obj`...``
| _hidden_methods = ``[``'``update``'``]``
| _id_attr = ``'``name``'``
| _json_resource_key = ``'``keypair``'``
| _json_resources_key = ``'``keypairs``'``
| _url_resource_path = ``'``/os-keypairs``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, public_key=`'``__UNDEF__``'`) | source code
Register a SSH public key Parameters: `name` (str) - Key name `public_key` (str) - content of SSH public key Returns: yakumo.nova.v2.key_pair.Resource Registered key Overrides: base.Manager.create

### _find_gen(self, **kwargs) | source code
Overrides: base.Manager._find_gen

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('name', 'name', mapper.Noop), ('fingerprint', 'fingerprint', mapper.
      Noop), ('public_key', 'public_key', mapper.Noop), ('user', 'user_id',
      mapper.Resource('user')), ('created_at', 'created_at', mapper.DateTime
      ), ('updated_at', 'updated_at', mapper.DateTime), ('deleted_at', 'dele
      ted_at', mapper.DateTime), ('is_deleted', 'deleted', mapper.Noop),]